@@ -681,7 +681,7 @@ MVP.Data.Map <- function(map, out='mvp', cols=1:5, header=TRUE, sep='\t', verbos
         map <- read.table(map, header = header, stringsAsFactors = FALSE)
     }
     map <- map[, cols]
-    colnames(map) <- c("SNP", "CHROM", "POS", "REF", "ALT")
+    colnames(map) <- c("SNP", "CHROM", "POS", "A1", "A2")
     if (length(unique(map[, 1])) != nrow(map)) {
         warning("WARNING: SNP is not unique and has been automatically renamed.")
         map[, 1] <- paste(map[, 2], map[, 3], sep = "-")
