@@ -35,7 +35,7 @@
     deltaExpStart = -5
     deltaExpEnd = 5
     snp.pool=snp.pool[,]
-    if(!is.null(snp.pool)&&var(snp.pool)==0){
+    if(!is.null(snp.pool)&&any(apply(snp.pool, 2, var)==0)){
         deltaExpStart = 100
         deltaExpEnd = deltaExpStart
     }
